@@ -30,7 +30,7 @@ from pilot.util.constants import SUCCESS, FAILURE, ERRNO_NOJOBS, PILOT_START_TIM
     SERVER_UPDATE_NOT_DONE, PILOT_MULTIJOB_START_TIME
 from pilot.util.filehandling import get_pilot_work_dir, mkdirs, establish_logging
 from pilot.util.harvester import is_harvester_mode
-from pilot.util.https import https_setup, send_update
+from pilot.util.https import get_panda_server, https_setup, send_update
 from pilot.util.timing import add_to_pilot_timing
 
 errors = ErrorCodes()
@@ -153,7 +153,7 @@ def get_args():
                             choices=['generic', 'generic_hpc',
                                      'production', 'production_hpc',
                                      'analysis', 'analysis_hpc',
-                                     'eventservice_hpc', 'stagein', 'payload_stageout'],
+                                     'eventservice_hpc', 'stager', 'payload_stageout'],
                             help='Pilot workflow (default: generic)')
 
     # graciously stop pilot process after hard limit
@@ -342,6 +342,10 @@ def get_args():
                             dest='input_dir',
                             default='',
                             help='Input directory')
+    arg_parser.add_argument('--input-destination-dir',
+                            dest='input_destination_dir',
+                            default='',
+                            help='Input destination directory')
     arg_parser.add_argument('--output-dir',
                             dest='output_dir',
                             default='',
@@ -452,9 +456,7 @@ def set_environment_variables():
         environ['PILOT_OUTPUT_DIR'] = args.output_dir
 
     # keep track of the server urls
-    _port = ":%s" % args.port
-    url = args.url if _port in args.url else args.url + _port
-    environ['PANDA_SERVER_URL'] = url
+    environ['PANDA_SERVER_URL'] = get_panda_server(args.url, args.port)
     environ['QUEUEDATA_SERVER_URL'] = '%s' % args.queuedata_url
 
 
@@ -582,12 +584,12 @@ if __name__ == '__main__':
     if exit_code != 0:
         sys.exit(exit_code)
 
-    # set environment variables (to be replaced with singleton implementation)
-    set_environment_variables()
-
     # setup and establish standard logging
     establish_logging(debug=args.debug, nopilotlog=args.nopilotlog)
 
+    # set environment variables (to be replaced with singleton implementation)
+    set_environment_variables()
+
     # execute main function
     trace = main()
 
