@@ -151,6 +151,7 @@ class ErrorCodes:
     CHECKSUMCALCFAILURE = 1366
     COMMANDTIMEDOUT = 1367
     REMOTEFILEOPENTIMEDOUT = 1368
+    FRONTIER = 1369
 
     _error_messages = {
         GENERALERROR: "General pilot error, consult batch log",
@@ -280,7 +281,8 @@ class ErrorCodes:
         NOCTYPES: "Python module ctypes not available on worker node",
         CHECKSUMCALCFAILURE: "Failure during checksum calculation",
         COMMANDTIMEDOUT: "Command timed out",
-        REMOTEFILEOPENTIMEDOUT: "Remote file open timed out"
+        REMOTEFILEOPENTIMEDOUT: "Remote file open timed out",
+        FRONTIER: "Frontier error"
     }
 
     put_error_codes = [1135, 1136, 1137, 1141, 1152, 1181]
